@@ -1,9 +1,12 @@
+from django.conf import settings
 from django.forms.fields import CharField
 from django.utils.translation import ugettext_lazy as _
 
 from cms import __version__ as cms_version
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
+
+from djangocms_text_ckeditor.settings import TEXT_CKEDITOR_CONFIGURATION
 from djangocms_text_ckeditor.widgets import TextEditorWidget
 from djangocms_text_ckeditor.models import Text
 from djangocms_text_ckeditor.utils import plugin_tags_to_user_html
@@ -16,13 +19,17 @@ class TextPlugin(CMSPluginBase):
     form = TextForm
     render_template = "cms/plugins/text.html"
     change_form_template = "cms/plugins/text_plugin_change_form.html"
+    ckeditor_configuration = TEXT_CKEDITOR_CONFIGURATION
 
     def get_editor_widget(self, request, plugins, pk, placeholder, language):
         """
         Returns the Django form Widget to be used for
         the text area
         """
-        return TextEditorWidget(installed_plugins=plugins, pk=pk, placeholder=placeholder, plugin_language=language)
+        return TextEditorWidget(installed_plugins=plugins, pk=pk,
+                                placeholder=placeholder,
+                                plugin_language=language,
+                                configuration=self.ckeditor_configuration)
 
     def get_form_class(self, request, plugins, pk, placeholder, language):
         """
@@ -54,6 +61,11 @@ class TextPlugin(CMSPluginBase):
         We override the change form template path
         to provide backwards compatibility with CMS 2.x
         """
+        ckeditor_basepath = '{0}/ckeditor/'.format(settings.STATIC_URL)
+        if ckeditor_basepath.startswith('//'):
+            protocol = 'https' if request.is_secure else 'http'
+            ckeditor_basepath = '{0}:{1}'.format(protocol, ckeditor_basepath)
+        context.update({'CKEDITOR_BASEPATH': ckeditor_basepath})
         if cms_version.startswith('2'):
             context['change_form_template'] = "admin/cms/page/plugin_change_form.html"
         return super(TextPlugin, self).render_change_form(request, context, add, change, form_url, obj)
